@@ -37,10 +37,65 @@ class CodecRegister(dict):
         ('application/json', '{\n "a": 1\n}')
         >>> reg.decode('application/json', '{"a": 1}')
         {'a': 1}
+
+    Since full media types can be rather unwieldy, you can also register
+    shorter aliases which will be resolved to their full counterparts first::
+
+        >>> reg.alias('json', 'application/json')
+        >>> reg.encode('json', {"a": 1})
+        ('application/json', '{"a": 1}')
+
+    Note that this only applies to encoding; for decoding, it's assumed that
+    full content type headers will be provided. If an alias is used as the
+    content type for a decode, a ``KeyError`` will be raised::
+
+        >>> reg.decode('json', '{"a": 1}')  # doctest: +ELLIPSIS
+        Traceback (most recent call last):
+        ...
+        KeyError: 'json'
     """
 
+    class _Alias(str):
+        """Sentinel class to represent a short alias to a longer media type."""
+        pass
+
+    def alias(self, alias_name, media_type):
+        self[alias_name] = self._Alias(media_type)
+
+    def get_codec(self, media_type):
+
+        """
+        Resolve a media type or alias to a codec and media type.
+
+            >>> reg = CodecRegister()
+            >>> reg['application/json'] = 123
+            >>> reg.alias('json', 'application/json')
+            >>> reg.get_codec('json')
+            ('application/json', 123)
+            >>> reg.get_codec('application/json')
+            ('application/json', 123)
+
+        This method will even deal with multiple levels of indirection,
+        considering the last name in the chain to be the full media type::
+
+            >>> reg.alias('json2', 'json')
+            >>> reg.get_codec('json2')
+            ('application/json', 123)
+            >>> reg.alias('json3', 'json2')
+            >>> reg.get_codec('json3')
+            ('application/json', 123)
+        """
+
+        last_ref = media_type
+        codec = self[media_type]
+        while isinstance(codec, self._Alias):
+            last_ref = codec
+            codec = self[last_ref]
+        return (last_ref, codec)
+
     def encode(self, media_type, obj, **params):
-        encoded = self[media_type].encode(media_type, obj, **params)
+        media_type, codec = self.get_codec(media_type)
+        encoded = codec.encode(media_type, obj, **params)
         if isinstance(encoded, str):
             return (media_type, encoded)
         return encoded
@@ -48,7 +103,12 @@ class CodecRegister(dict):
     def decode(self, content_type, bytes):
         if not isinstance(content_type, ContentType):
             content_type = ContentType(content_type)
-        return self[content_type.media_type].decode(content_type, bytes)
+
+        codec = self[content_type.media_type]
+        if isinstance(codec, self._Alias):
+            raise KeyError(content_type.media_type)
+
+        return codec.decode(content_type, bytes)
 
 
 class Codec(object):
