@@ -25,7 +25,7 @@ def requests_http_backend(api, method, url, *args, **kwargs):
                         content=http_response.content,
                         codec_register=codec_register)
 
-    if response.status_code // 100 != 2:
+    if response.status_code and (response.status_code // 100 != 2):
         raise ResponseException(response)
     elif http_response.error:
         raise http_response.error
